@@ -681,6 +681,7 @@ int sc_transmit_apdu(sc_card_t *card, sc_apdu_t *apdu);
 void sc_format_apdu(sc_card_t *card, sc_apdu_t *apdu, int cse, int ins,
 		    int p1, int p2);
 
+int sc_check_sw(struct sc_card *card, unsigned int sw1, unsigned int sw2);
 
 /********************************************************************/
 /*                  opensc context functions                        */
@@ -1170,36 +1171,7 @@ extern const char *sc_get_version(void);
 		return drv_version; \
 	}
 
-extern struct sc_reader_driver *sc_get_pcsc_driver(void);
-extern struct sc_reader_driver *sc_get_ctapi_driver(void);
-extern struct sc_reader_driver *sc_get_openct_driver(void);
-
-extern sc_card_driver_t *sc_get_rutoken_driver(void);
-extern sc_card_driver_t *sc_get_default_driver(void);
-extern sc_card_driver_t *sc_get_emv_driver(void);
-extern sc_card_driver_t *sc_get_cardos_driver(void);
-extern sc_card_driver_t *sc_get_cryptoflex_driver(void);
-extern sc_card_driver_t *sc_get_cyberflex_driver(void);
-extern sc_card_driver_t *sc_get_gpk_driver(void);
-extern sc_card_driver_t *sc_get_gemsafeV1_driver(void);
 extern sc_card_driver_t *sc_get_iso7816_driver(void);
-extern sc_card_driver_t *sc_get_miocos_driver(void);
-extern sc_card_driver_t *sc_get_mcrd_driver(void);
-extern sc_card_driver_t *sc_get_setcos_driver(void);
-extern sc_card_driver_t *sc_get_starcos_driver(void);
-extern sc_card_driver_t *sc_get_tcos_driver(void);
-extern sc_card_driver_t *sc_get_openpgp_driver(void);
-extern sc_card_driver_t *sc_get_jcop_driver(void);
-extern sc_card_driver_t *sc_get_oberthur_driver(void);
-extern sc_card_driver_t *sc_get_belpic_driver(void);
-extern sc_card_driver_t *sc_get_atrust_acos_driver(void);
-extern sc_card_driver_t *sc_get_incrypto34_driver(void);
-extern sc_card_driver_t *sc_get_piv_driver(void);
-extern sc_card_driver_t *sc_get_muscle_driver(void);
-extern sc_card_driver_t *sc_get_acos5_driver(void);
-extern sc_card_driver_t *sc_get_asepcos_driver(void);
-extern sc_card_driver_t *sc_get_akis_driver(void);
-extern sc_card_driver_t *sc_get_entersafe_driver(void);
 
 #ifdef __cplusplus
 }
